@@ -1,28 +1,26 @@
 from __future__ import annotations
 
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any
 
 from asphalt.core import resolve_reference
 from msgpack import ExtType, packb, unpackb
-from typeguard import check_argument_types
 
-from asphalt.serialization.api import CustomizableSerializer
-from asphalt.serialization.object_codec import DefaultCustomTypeCodec
+from ..api import CustomizableSerializer
+from ..object_codec import DefaultCustomTypeCodec
 
 
-class MsgpackTypeCodec(DefaultCustomTypeCodec):
+class MsgpackTypeCodec(DefaultCustomTypeCodec["MsgpackSerializer"]):
     """
     Default custom type codec implementation for :class:`~.MsgpackSerializer`.
 
-    Wraps marshalled state in either msgpack's ExtType objects (the default) or dicts (with
-    ``type_code=None``).
+    Wraps marshalled state in either msgpack's ExtType objects (the default) or dicts
+    (with ``type_code=None``).
 
-    :param type_code: msgpack type code to use, or ``None`` to use JSON compatible dict-based
-        wrapping
+    :param type_code: msgpack type code to use, or ``None`` to use JSON compatible
+        dict-based wrapping
     """
 
-    def __init__(self, type_code: Optional[int] = 119, **kwargs):
-        assert check_argument_types()
+    def __init__(self, type_code: int | None = 119, **kwargs: Any):
         super().__init__(**kwargs)
         self.type_code = type_code
 
@@ -41,19 +39,19 @@ class MsgpackTypeCodec(DefaultCustomTypeCodec):
         else:
             serializer.unpacker_options["object_hook"] = self.default_decoder
 
-    def ext_hook(self, code: int, data: bytes):
+    def ext_hook(self, code: int, data: bytes) -> Any:
         if code == self.type_code:
             return self.default_decoder(data)
         else:
             return ExtType(code, data)
 
-    def wrap_state_ext_type(self, typename: str, state):
+    def wrap_state_ext_type(self, typename: str, state: Any) -> ExtType:
         data = typename.encode("utf-8") + b":" + self.serializer.serialize(state)
         return ExtType(self.type_code, data)
 
     def unwrap_state_ext_type(
         self, wrapped_state: bytes
-    ) -> Union[Tuple[str, Any], Tuple[None, None]]:
+    ) -> tuple[str, Any] | tuple[None, None]:
         typename, payload = wrapped_state.split(b":", 1)
         return typename.decode("utf-8"), self.serializer.deserialize(payload)
 
@@ -62,15 +60,15 @@ class MsgpackSerializer(CustomizableSerializer):
     """
     Serializes objects using the msgpack library.
 
-    The following defaults are passed to packer/unpacker and can be overridden by setting values
-    for the options explicitly:
+    The following defaults are passed to packer/unpacker and can be overridden by
+    setting values for the options explicitly:
 
     * ``use_bin_type=True`` (packer)
     * ``raw=False`` (unpacker)
 
     To use this serializer backend, the ``msgpack`` library must be installed.
-    A convenient way to do this is to install ``asphalt-serialization`` with the ``msgpack``
-    extra:
+    A convenient way to do this is to install ``asphalt-serialization`` with the
+    ``msgpack`` extra:
 
     .. code-block:: shell
 
@@ -80,8 +78,8 @@ class MsgpackSerializer(CustomizableSerializer):
 
     :param packer_options: keyword arguments passed to :func:`msgpack.packb`
     :param unpacker_options: keyword arguments passed to :func:`msgpack.unpackb`
-    :param custom_type_codec: wrapper to use to wrap custom types after marshalling, or ``None`` to
-        return marshalled objects as-is
+    :param custom_type_codec: wrapper to use to wrap custom types after marshalling, or
+        ``None`` to return marshalled objects as-is
     """
 
     __slots__ = (
@@ -94,23 +92,22 @@ class MsgpackSerializer(CustomizableSerializer):
 
     def __init__(
         self,
-        packer_options: Dict[str, Any] = None,
-        unpacker_options: Dict[str, Any] = None,
-        custom_type_codec: Union[MsgpackTypeCodec, str] = None,
+        packer_options: dict[str, Any] | None = None,
+        unpacker_options: dict[str, Any] | None = None,
+        custom_type_codec: MsgpackTypeCodec | str | None = None,
     ) -> None:
-        assert check_argument_types()
         super().__init__(resolve_reference(custom_type_codec) or MsgpackTypeCodec())
-        self.packer_options = packer_options or {}
+        self.packer_options: dict[str, Any] = packer_options or {}
         self.packer_options.setdefault("use_bin_type", True)
-        self.unpacker_options = unpacker_options or {}
+        self.unpacker_options: dict[str, Any] = unpacker_options or {}
         self.unpacker_options.setdefault("raw", False)
 
-    def serialize(self, obj) -> bytes:
-        return packb(obj, **self.packer_options)
+    def serialize(self, obj: Any) -> bytes:
+        return packb(obj, **self.packer_options)  # type: ignore[no-any-return]
 
-    def deserialize(self, payload: bytes):
+    def deserialize(self, payload: bytes) -> Any:
         return unpackb(payload, **self.unpacker_options)
 
     @property
-    def mimetype(self):
+    def mimetype(self) -> str:
         return "application/msgpack"
